pub struct ConsensusFinalizedBlockHeader {Show 18 fields
pub number: BlockNumber,
pub timestamp: BlockTimestamp,
pub eth_l1_gas_price: GasPrice,
pub strk_l1_gas_price: GasPrice,
pub eth_l1_data_gas_price: GasPrice,
pub strk_l1_data_gas_price: GasPrice,
pub eth_l2_gas_price: GasPrice,
pub strk_l2_gas_price: GasPrice,
pub sequencer_address: SequencerAddress,
pub starknet_version: StarknetVersion,
pub event_commitment: EventCommitment,
pub transaction_commitment: TransactionCommitment,
pub transaction_count: usize,
pub event_count: usize,
pub l1_da_mode: L1DataAvailabilityMode,
pub receipt_commitment: ReceiptCommitment,
pub state_diff_commitment: StateDiffCommitment,
pub state_diff_length: u64,
}Expand description
An L2 BlockHeader that is the result of executing a consensus proposal that was decided upon. The only differences from a BlockHeader are:
- the state tries have not been updated yet, so the state commitment is missing,
- in consequence the block hash could not have been computed yet,
- parent hash is updated when the header is transformed into a full BlockHeader to avoid additional DB lookup in consensus.
Fields
number: BlockNumbertimestamp: BlockTimestampeth_l1_gas_price: GasPricestrk_l1_gas_price: GasPriceeth_l1_data_gas_price: GasPricestrk_l1_data_gas_price: GasPriceeth_l2_gas_price: GasPricestrk_l2_gas_price: GasPricesequencer_address: SequencerAddressstarknet_version: StarknetVersionevent_commitment: EventCommitmenttransaction_commitment: TransactionCommitmenttransaction_count: usizeevent_count: usizel1_da_mode: L1DataAvailabilityModereceipt_commitment: ReceiptCommitmentstate_diff_commitment: StateDiffCommitmentstate_diff_length: u64Implementations
Sourceimpl ConsensusFinalizedBlockHeader
impl ConsensusFinalizedBlockHeader
pub fn compute_hash( self, parent_hash: BlockHash, state_commitment: StateCommitment, block_hash_fn: impl Fn(&BlockHeader) -> BlockHash, ) -> BlockHeader