pub type DecidedBlocks = Arc<RwLock<BTreeMap<BlockNumber, DecidedBlock>>>;Expand description
A type alias for a Sync collection of DecidedBlock-s
Aliased Type
pub struct DecidedBlocks { /* private fields */ }pub type DecidedBlocks = Arc<RwLock<BTreeMap<BlockNumber, DecidedBlock>>>;A type alias for a Sync collection of DecidedBlock-s
pub struct DecidedBlocks { /* private fields */ }